Remove unnecessary attribute data from iteration results objects
created by tune_grid and tune_bayes.
This makes the parameter object significantly smaller when saved to disk.
Remove unnecessary attribute data from iteration results objects
created by tune_grid and tune_bayes.
This makes the parameter object significantly smaller when saved to disk.