For some models, predictions can be made on sub-models in the model object.
Usage
# S3 method for class '`_lgb.Booster`'
multi_predict(object, new_data, type = NULL, trees = NULL, ...)Arguments
- object
A model_fit object.
- new_data
A rectangular data object, such as a data frame.
- type
A single character value or NULL. Possible values are "numeric", "class", "prob", "conf_int", "pred_int", "quantile", or "raw". When NULL,
predict()will choose an appropriate value based on the model's mode.- trees
An integer vector for the number of trees in the ensemble.
- ...
Optional arguments to pass to
predict.model_fit(type = "raw"), such as type.