Skip to contents

Not intended for direct use.

Usage

pred_lgb_reg_num(object, new_data, type = NULL, ...)

Arguments

object

A fitted object.

new_data

Data frame in which to look for variables with which to predict.

type

Prediction type passed to predict.lgb.Booster(). When NULL (the default), uses "raw" for models trained with a custom objective and "response" otherwise.

...

Additional named arguments passed to the predict() method of the lgb.Booster object.