Not intended for direct use.
Arguments
- object
A fitted object.
- new_data
Data frame in which to look for variables with which to predict.
- ...
Additional named arguments passed to the
predict()method of thelgb.Boosterobject.
Not intended for direct use.
A fitted object.
Data frame in which to look for variables with which to predict.
Additional named arguments passed to the predict() method
of the lgb.Booster object.